betty.ancestry.citation module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.citation module

Data types for citations.

final class betty.ancestry.citation.Citation

  Bases: `ShorthandPluginBase`, `HasDate`, `HasFileReferences`, `HasPrivacy`, `HasLinks`, `UserFacingEntity`

  A citation (a reference to a source).

  __init__(*, source: Source | ToOneResolver[Source], id: str | None = None, facts: Iterable['HasCitations & Entity'] | ToManyResolver['HasCitations'] | None = None, location: ShorthandStaticTranslations | None = None, date: Datey | None = None, file_references: Iterable[FileReference] | ToManyResolver[FileReference] | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None)
  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  facts

    A bidirectional *-to-many entity type association.

  property label: Localizable

    The entity’s human-readable label.

  location

    The human-readable citation location.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  source

    A bidirectional *-to-one entity type association.